"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.analyzeComponentUsageGenerator = exports.analyzeComponentUsageDescription = void 0;
const tslib_1 = require("tslib");
const utils_1 = require("../../../utils");
const designSystem_1 = require("../../actions/designSystem");
const messages_1 = require("../../messages");
const applyRuntimeArgs = (prevAns = {}) => {
    if (prevAns.useCurrent === undefined) {
        prevAns.useCurrent = utils_1.argv.useCurrent;
    }
    if (!prevAns.targetDirectory) {
        prevAns.targetDirectory = utils_1.argv.targetDirectory;
    }
    return prevAns;
};
exports.analyzeComponentUsageDescription = 'Analyse component usage under the target directory.';
exports.analyzeComponentUsageGenerator = {
    description: (0, messages_1.generatorDescription)(exports.analyzeComponentUsageDescription),
    prompts(inquirer, prevAns = {}) {
        return tslib_1.__awaiter(this, void 0, void 0, function* () {
            prevAns = applyRuntimeArgs(prevAns);
            const { useCurrent = prevAns.useCurrent, targetDirectory = prevAns.targetDirectory } = yield inquirer.prompt([
                {
                    name: 'useCurrent',
                    type: 'confirm',
                    message: 'Use current directory',
                    when: !prevAns.targetDirectory,
                    default: false,
                },
                {
                    name: 'targetDirectory',
                    type: 'select-directory',
                    message: 'Target directory',
                    when: (data) => !prevAns.targetDirectory && !data.useCurrent,
                    basePath: utils_1.basePath,
                },
            ]);
            return {
                useCurrent,
                targetDirectory: useCurrent ? process.cwd() : targetDirectory,
            };
        });
    },
    actions: (answers) => {
        return [
            {
                type: designSystem_1.DesignSystemActionType.analyzeComponentUsage,
                get directory() {
                    return answers.targetDirectory;
                },
                abortOnFail: true,
            },
            ' Please review suggestions and action where necessary.',
        ];
    },
};
