"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.isEnabled = exports.disable = exports.warn = exports.error = exports.info = exports.verbose = exports.debug = void 0;
const tslib_1 = require("tslib");
const chalk_1 = tslib_1.__importDefault(require("chalk"));
const IS_TEST_RUN = process.env.NODE_ENV === 'test';
// disable logs if running inside a test
let enabled = IS_TEST_RUN ? false : true;
function log(isError, color, ...text) {
    // errors are always emitted, even if logs are disabled
    if (!enabled && !isError) {
        return;
    }
    console.error(`${color(...text)}`);
}
function debug(...text) {
    if (process.env.DEBUG) {
        log(false, chalk_1.default.gray, ...text);
    }
}
exports.debug = debug;
function verbose(...text) {
    log(false, chalk_1.default.white, ...text);
}
exports.verbose = verbose;
function info(...text) {
    log(false, chalk_1.default.cyan, ...text);
}
exports.info = info;
function error(...text) {
    log(true, chalk_1.default.red, ...text);
}
exports.error = error;
function warn(...text) {
    log(false, chalk_1.default.yellow, ...text);
}
exports.warn = warn;
function disable() {
    enabled = false;
}
exports.disable = disable;
function isEnabled() {
    return enabled;
}
exports.isEnabled = isEnabled;
